@@ -231,22 +231,12 @@ public final class XmlDataImporter extends ConnectionConfigurationAbtract {
    }
 
    private static URL findResource(final String resourceName) {
-      return AccessController.doPrivileged(new PrivilegedAction<URL>() {
-         @Override
-         public URL run() {
-            return ClassloadingUtil.findResource(resourceName);
-         }
-      });
+      return AccessController.doPrivileged((PrivilegedAction<URL>) () -> ClassloadingUtil.findResource(resourceName));
    }
 
    private void processXml() throws Exception {
       if (sort) {
-         messages = new TreeSet<XMLMessageImporter.MessageInfo>(new Comparator<XMLMessageImporter.MessageInfo>() {
-            @Override
-            public int compare(XMLMessageImporter.MessageInfo o1, XMLMessageImporter.MessageInfo o2) {
-               return Long.compare(o1.id, o2.id);
-            }
-         });
+         messages = new TreeSet<XMLMessageImporter.MessageInfo>(Comparator.comparingLong(o -> o.id));
       }
       while (reader.hasNext()) {
          if (logger.isDebugEnabled()) {
@@ -357,7 +347,7 @@ public final class XmlDataImporter extends ConnectionConfigurationAbtract {
       }
 
       message.putBytesProperty(Message.HDR_ROUTE_TO_IDS, buffer.array());
-      producer.send(SimpleString.toSimpleString(destination), message);
+      producer.send(SimpleString.of(destination), message);
    }
 
    private void oldBinding() throws Exception {
@@ -416,17 +406,17 @@ public final class XmlDataImporter extends ConnectionConfigurationAbtract {
       }
 
 
-      ClientSession.AddressQuery addressQuery = session.addressQuery(SimpleString.toSimpleString(address));
+      ClientSession.AddressQuery addressQuery = session.addressQuery(SimpleString.of(address));
 
       if (!addressQuery.isExists()) {
-         session.createAddress(SimpleString.toSimpleString(address), routingType, true);
+         session.createAddress(SimpleString.of(address), routingType, true);
       }
 
       if (!filter.equals(FilterImpl.GENERIC_IGNORED_FILTER)) {
-         ClientSession.QueueQuery queueQuery = session.queueQuery(new SimpleString(queueName));
+         ClientSession.QueueQuery queueQuery = session.queueQuery(SimpleString.of(queueName));
 
          if (!queueQuery.isExists()) {
-            session.createQueue(new QueueConfiguration(queueName).setAddress(address).setRoutingType(routingType).setFilterString(filter));
+            session.createQueue(QueueConfiguration.of(queueName).setAddress(address).setRoutingType(routingType).setFilterString(filter));
             if (logger.isDebugEnabled()) {
                logger.debug("Binding queue(name={}, address={}, filter={})", queueName, address, filter);
             }
@@ -463,10 +453,10 @@ public final class XmlDataImporter extends ConnectionConfigurationAbtract {
          }
       }
 
-      ClientSession.QueueQuery queueQuery = session.queueQuery(new SimpleString(queueName));
+      ClientSession.QueueQuery queueQuery = session.queueQuery(SimpleString.of(queueName));
 
       if (!queueQuery.isExists()) {
-         session.createQueue(new QueueConfiguration(queueName).setAddress(address).setRoutingType(RoutingType.valueOf(routingType)).setFilterString(filter));
+         session.createQueue(QueueConfiguration.of(queueName).setAddress(address).setRoutingType(RoutingType.valueOf(routingType)).setFilterString(filter));
          if (logger.isDebugEnabled()) {
             logger.debug("Binding queue(name={}, address={}, filter={})", queueName, address, filter);
          }
@@ -493,14 +483,14 @@ public final class XmlDataImporter extends ConnectionConfigurationAbtract {
          }
       }
 
-      ClientSession.AddressQuery addressQuery = session.addressQuery(new SimpleString(addressName));
+      ClientSession.AddressQuery addressQuery = session.addressQuery(SimpleString.of(addressName));
 
       if (!addressQuery.isExists()) {
          EnumSet<RoutingType> set = EnumSet.noneOf(RoutingType.class);
          for (String routingType : ListUtil.toList(routingTypes)) {
             set.add(RoutingType.valueOf(routingType));
          }
-         session.createAddress(SimpleString.toSimpleString(addressName), set, false);
+         session.createAddress(SimpleString.of(addressName), set, false);
          logger.debug("Binding address(name={}, routingTypes={})", addressName, routingTypes);
       } else {
          logger.debug("Binding {} already exists so won't re-bind.", addressName);
