@@ -1,13 +1,13 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * <p>
- * http://www.apache.org/licenses/LICENSE-2.0
- * <p>
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -499,21 +499,18 @@ public class BrokerService implements Service {
       connector.setLocalUri(this.getConnectURI());
       // Set a connection filter so that the connector does not establish loop
       // back connections.
-      connector.setConnectionFilter(new ConnectionFilter() {
-         @Override
-         public boolean connectTo(URI location) {
-            List<TransportConnector> transportConnectors = getTransportConnectors();
-            for (Iterator<TransportConnector> iter = transportConnectors.iterator(); iter.hasNext(); ) {
-               try {
-                  TransportConnector tc = iter.next();
-                  if (location.equals(tc.getConnectUri())) {
-                     return false;
-                  }
-               } catch (Throwable e) {
+      connector.setConnectionFilter(location -> {
+         List<TransportConnector> transportConnectors = getTransportConnectors();
+         for (Iterator<TransportConnector> iter = transportConnectors.iterator(); iter.hasNext(); ) {
+            try {
+               TransportConnector tc = iter.next();
+               if (location.equals(tc.getConnectUri())) {
+                  return false;
                }
+            } catch (Throwable e) {
             }
-            return true;
          }
+         return true;
       });
 
       networkConnectors.add(connector);
@@ -819,6 +816,3 @@ public class BrokerService implements Service {
       }
    }
 }
-
-
-
