@@ -16,6 +16,19 @@
  */
 package org.apache.activemq.artemis.tests.integration.amqp;
 
+import javax.jms.BytesMessage;
+import javax.jms.Connection;
+import javax.jms.DeliveryMode;
+import javax.jms.Destination;
+import javax.jms.JMSException;
+import javax.jms.Message;
+import javax.jms.MessageConsumer;
+import javax.jms.MessageProducer;
+import javax.jms.QueueBrowser;
+import javax.jms.Session;
+import javax.jms.TextMessage;
+import javax.jms.Topic;
+import java.lang.invoke.MethodHandles;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.Random;
@@ -26,163 +39,34 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import javax.jms.BytesMessage;
-import javax.jms.Connection;
-import javax.jms.DeliveryMode;
-import javax.jms.Destination;
-import javax.jms.JMSException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageListener;
-import javax.jms.MessageProducer;
-import javax.jms.QueueBrowser;
-import javax.jms.Session;
-import javax.jms.TextMessage;
-import javax.jms.Topic;
-
-import org.apache.activemq.artemis.api.core.QueueConfiguration;
-import org.apache.activemq.artemis.api.core.RoutingType;
 import org.apache.activemq.artemis.core.server.Queue;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.tests.util.Wait;
-import org.apache.activemq.artemis.utils.DestinationUtil;
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.policy.JmsDefaultPrefetchPolicy;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import java.lang.invoke.MethodHandles;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 public class JMSMessageConsumerTest extends JMSClientTestSupport {
 
    protected static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
-   @Override
-   protected String getConfiguredProtocols() {
-      return "AMQP,OPENWIRE,CORE";
-   }
-
-   @Test(timeout = 30000)
-   public void testDeliveryModeAMQPProducerCoreConsumer() throws Exception {
-      Connection connection = createConnection(); //AMQP
-      Connection connection2 = createCoreConnection(); //CORE
-      testDeliveryMode(connection, connection2);
-   }
-
-   @Test(timeout = 30000)
-   public void testDeliveryModeAMQPProducerAMQPConsumer() throws Exception {
-      Connection connection = createConnection(); //AMQP
-      Connection connection2 = createConnection(); //AMQP
-      testDeliveryMode(connection, connection2);
-   }
-
-   @Test(timeout = 30000)
-   public void testDeliveryModeCoreProducerAMQPConsumer() throws Exception {
-      Connection connection = createCoreConnection(); //CORE
-      Connection connection2 = createConnection(); //AMQP
-      testDeliveryMode(connection, connection2);
-   }
-
-   @Test(timeout = 30000)
-   public void testDeliveryModeCoreProducerCoreConsumer() throws Exception {
-      Connection connection = createCoreConnection(); //CORE
-      Connection connection2 = createCoreConnection(); //CORE
-      testDeliveryMode(connection, connection2);
-   }
-
-   private void testDeliveryMode(Connection connection1, Connection connection2) throws JMSException {
-      try {
-         Session session1 = connection1.createSession(false, Session.AUTO_ACKNOWLEDGE);
-         Session session2 = connection2.createSession(false, Session.AUTO_ACKNOWLEDGE);
-
-         javax.jms.Queue queue1 = session1.createQueue(getQueueName());
-         javax.jms.Queue queue2 = session2.createQueue(getQueueName());
-
-         final MessageConsumer consumer2 = session2.createConsumer(queue2);
-
-         MessageProducer producer = session1.createProducer(queue1);
-         producer.setDeliveryMode(DeliveryMode.PERSISTENT);
-         connection1.start();
-
-         TextMessage message = session1.createTextMessage();
-         message.setText("hello");
-         producer.send(message);
-
-         Message received = consumer2.receive(100);
-
-         assertNotNull("Should have received a message by now.", received);
-         assertTrue("Should be an instance of TextMessage", received instanceof TextMessage);
-         assertEquals(DeliveryMode.PERSISTENT, received.getJMSDeliveryMode());
-      } finally {
-         connection1.close();
-         connection2.close();
-      }
-   }
-
-   @Test(timeout = 30000)
-   public void testPriorityAMQPProducerCoreConsumer() throws Exception {
-      Connection connection = createConnection(); //AMQP
-      Connection connection2 = createCoreConnection(); //CORE
-      testPriority(connection, connection2);
-   }
-
-   @Test(timeout = 30000)
-   public void testPriorityAMQPProducerAMQPConsumer() throws Exception {
-      Connection connection = createConnection(); //AMQP
-      Connection connection2 = createConnection(); //AMQP
-      testPriority(connection, connection2);
-   }
-
-   @Test(timeout = 30000)
-   public void testPriorityModeCoreProducerAMQPConsumer() throws Exception {
-      Connection connection = createCoreConnection(); //CORE
-      Connection connection2 = createConnection(); //AMQP
-      testPriority(connection, connection2);
-   }
-
-   @Test(timeout = 30000)
-   public void testPriorityCoreProducerCoreConsumer() throws Exception {
-      Connection connection = createCoreConnection(); //CORE
-      Connection connection2 = createCoreConnection(); //CORE
-      testPriority(connection, connection2);
-   }
-
-   private void testPriority(Connection connection1, Connection connection2) throws JMSException {
-      try {
-         Session session1 = connection1.createSession(false, Session.AUTO_ACKNOWLEDGE);
-         Session session2 = connection2.createSession(false, Session.AUTO_ACKNOWLEDGE);
-
-         javax.jms.Queue queue1 = session1.createQueue(getQueueName());
-         javax.jms.Queue queue2 = session2.createQueue(getQueueName());
-
-         final MessageConsumer consumer2 = session2.createConsumer(queue2);
-
-         MessageProducer producer = session1.createProducer(queue1);
-         producer.setPriority(2);
-         connection1.start();
-
-         TextMessage message = session1.createTextMessage();
-         message.setText("hello");
-         producer.send(message);
-
-         Message received = consumer2.receive(100);
-
-         assertNotNull("Should have received a message by now.", received);
-         assertTrue("Should be an instance of TextMessage", received instanceof TextMessage);
-         assertEquals(2, received.getJMSPriority());
-      } finally {
-         connection1.close();
-         connection2.close();
-      }
-   }
-
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testSelectorOnTopic() throws Exception {
       doTestSelector(true);
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testSelectorOnQueue() throws Exception {
       doTestSelector(false);
    }
@@ -221,53 +105,14 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       }
    }
 
-   @Test(timeout = 60000)
-   public void testDurableSubscriptionWithConfigurationManagedQueueWithCore() throws Exception {
-      testDurableSubscriptionWithConfigurationManagedQueue(() -> createCoreConnection(false));
-
-   }
-
-   @Test(timeout = 60000)
-   public void testDurableSubscriptionWithConfigurationManagedQueueWithOpenWire() throws Exception {
-      testDurableSubscriptionWithConfigurationManagedQueue(() -> createOpenWireConnection(false));
-
-   }
-
-   @Test(timeout = 60000)
-   public void testDurableSubscriptionWithConfigurationManagedQueueWithAMQP() throws Exception {
-      testDurableSubscriptionWithConfigurationManagedQueue(() -> JMSMessageConsumerTest.super.createConnection(false));
-   }
-
-   private void testDurableSubscriptionWithConfigurationManagedQueue(ConnectionSupplier connectionSupplier) throws Exception {
-      final String clientId = "bar";
-      final String subName = "foo";
-      final String queueName = DestinationUtil.createQueueNameForSubscription(true, clientId, subName).toString();
-      server.stop();
-      server.getConfiguration().addQueueConfiguration(new QueueConfiguration(queueName).setAddress("myTopic").setFilterString("color = 'BLUE'").setRoutingType(RoutingType.MULTICAST));
-      server.getConfiguration().setAmqpUseCoreSubscriptionNaming(true);
-      server.start();
-
-      try (Connection connection = connectionSupplier.createConnection()) {
-         connection.setClientID(clientId);
-         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-         Topic destination = session.createTopic("myTopic");
-
-         MessageConsumer messageConsumer = session.createDurableSubscriber(destination, subName);
-         messageConsumer.close();
-
-         Queue queue = server.locateQueue(queueName);
-         assertNotNull(queue);
-         assertNotNull(queue.getFilter());
-         assertEquals("color = 'BLUE'", queue.getFilter().getFilterString().toString());
-      }
-   }
-
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSTypeOnTopic() throws Exception {
       doTestSelectorsWithJMSType(true);
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSTypeOnQueue() throws Exception {
       doTestSelectorsWithJMSType(false);
    }
@@ -302,14 +147,15 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
          Message msg = consumer.receive(2000);
          assertNotNull(msg);
          assertTrue(msg instanceof TextMessage);
-         assertEquals("Unexpected JMSType value", type, msg.getJMSType());
-         assertEquals("Unexpected message content", "text + type", ((TextMessage) msg).getText());
+         assertEquals(type, msg.getJMSType(), "Unexpected JMSType value");
+         assertEquals("text + type", ((TextMessage) msg).getText(), "Unexpected message content");
       } finally {
          connection.close();
       }
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSCorrelationID() throws Exception {
       Connection connection = createConnection();
 
@@ -344,14 +190,15 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
          Message msg = consumer.receive(2000);
          assertNotNull(msg);
          assertTrue(msg instanceof TextMessage);
-         assertEquals("Unexpected JMSCorrelationID value", correlationID, msg.getJMSCorrelationID());
-         assertEquals("Unexpected message content", "JMSCorrelationID", ((TextMessage) msg).getText());
+         assertEquals(correlationID, msg.getJMSCorrelationID(), "Unexpected JMSCorrelationID value");
+         assertEquals("JMSCorrelationID", ((TextMessage) msg).getText(), "Unexpected message content");
       } finally {
          connection.close();
       }
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSPriority() throws Exception {
       Connection connection = createConnection();
 
@@ -389,12 +236,14 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       }
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSXGroupIDOnTopic() throws Exception {
       doTestSelectorsWithJMSXGroupID(true);
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSXGroupIDOnQueue() throws Exception {
       doTestSelectorsWithJMSXGroupID(false);
    }
@@ -447,7 +296,8 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       }
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSDeliveryOnQueue() throws Exception {
       final Connection connection = createConnection();
 
@@ -473,14 +323,15 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
          Message msg = consumer.receive(2000);
          assertNotNull(msg);
          assertTrue(msg instanceof TextMessage);
-         assertEquals("Unexpected JMSDeliveryMode value", DeliveryMode.PERSISTENT, msg.getJMSDeliveryMode());
-         assertEquals("Unexpected message content", "persistent", ((TextMessage) msg).getText());
+         assertEquals(DeliveryMode.PERSISTENT, msg.getJMSDeliveryMode(), "Unexpected JMSDeliveryMode value");
+         assertEquals("persistent", ((TextMessage) msg).getText(), "Unexpected message content");
       } finally {
          connection.close();
       }
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSTimestampOnQueue() throws Exception {
       final Connection connection = createConnection();
 
@@ -508,14 +359,15 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
          Message msg = consumer.receive(2000);
          assertNotNull(msg);
          assertTrue(msg instanceof TextMessage);
-         assertEquals("Unexpected JMSTimestamp value", message2.getJMSTimestamp(), msg.getJMSTimestamp());
-         assertEquals("Unexpected message content", "expected", ((TextMessage) msg).getText());
+         assertEquals(message2.getJMSTimestamp(), msg.getJMSTimestamp(), "Unexpected JMSTimestamp value");
+         assertEquals("expected", ((TextMessage) msg).getText(), "Unexpected message content");
       } finally {
          connection.close();
       }
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testSelectorsWithJMSExpirationOnQueue() throws Exception {
       final Connection connection = createConnection();
 
@@ -540,14 +392,15 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
          Message msg = consumer.receive(2000);
          assertNotNull(msg);
          assertTrue(msg instanceof TextMessage);
-         assertEquals("Unexpected JMSExpiration value", message2.getJMSExpiration(), msg.getJMSExpiration());
-         assertEquals("Unexpected message content", "expected", ((TextMessage) msg).getText());
+         assertEquals(message2.getJMSExpiration(), msg.getJMSExpiration(), "Unexpected JMSExpiration value");
+         assertEquals("expected", ((TextMessage) msg).getText(), "Unexpected message content");
       } finally {
          connection.close();
       }
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testJMSSelectorFiltersJMSMessageIDOnTopic() throws Exception {
       Connection connection = createConnection();
 
@@ -578,7 +431,8 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       }
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testZeroPrefetchWithTwoConsumers() throws Exception {
       JmsConnection connection = (JmsConnection) createConnection();
       ((JmsDefaultPrefetchPolicy) connection.getPrefetchPolicy()).setAll(0);
@@ -596,31 +450,35 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       MessageConsumer consumer2 = session.createConsumer(queue);
       TextMessage answer = (TextMessage) consumer1.receive(5000);
       assertNotNull(answer);
-      assertEquals("Should have received a message!", answer.getText(), "Msg1");
+      assertEquals(answer.getText(), "Msg1", "Should have received a message!");
       answer = (TextMessage) consumer2.receive(5000);
       assertNotNull(answer);
-      assertEquals("Should have received a message!", answer.getText(), "Msg2");
+      assertEquals(answer.getText(), "Msg2", "Should have received a message!");
 
       answer = (TextMessage) consumer2.receiveNoWait();
-      assertNull("Should have not received a message!", answer);
+      assertNull(answer, "Should have not received a message!");
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testProduceAndConsumeLargeNumbersOfTopicMessagesClientAck() throws Exception {
       doTestProduceAndConsumeLargeNumbersOfMessages(true, Session.CLIENT_ACKNOWLEDGE);
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testProduceAndConsumeLargeNumbersOfQueueMessagesClientAck() throws Exception {
       doTestProduceAndConsumeLargeNumbersOfMessages(false, Session.CLIENT_ACKNOWLEDGE);
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testProduceAndConsumeLargeNumbersOfTopicMessagesAutoAck() throws Exception {
       doTestProduceAndConsumeLargeNumbersOfMessages(true, Session.AUTO_ACKNOWLEDGE);
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testProduceAndConsumeLargeNumbersOfQueueMessagesAutoAck() throws Exception {
       doTestProduceAndConsumeLargeNumbersOfMessages(false, Session.AUTO_ACKNOWLEDGE);
    }
@@ -643,16 +501,12 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       }
 
       MessageConsumer consumer = session.createConsumer(destination);
-      consumer.setMessageListener(new MessageListener() {
-
-         @Override
-         public void onMessage(Message message) {
-            try {
-               message.acknowledge();
-               done.countDown();
-            } catch (JMSException ex) {
-               logger.debug("Caught exception.", ex);
-            }
+      consumer.setMessageListener(message -> {
+         try {
+            message.acknowledge();
+            done.countDown();
+         } catch (JMSException ex) {
+            logger.debug("Caught exception.", ex);
          }
       });
 
@@ -665,10 +519,11 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
          producer.send(textMessage);
       }
 
-      assertTrue("Did not receive all messages: " + MSG_COUNT, done.await(15, TimeUnit.SECONDS));
+      assertTrue(done.await(15, TimeUnit.SECONDS), "Did not receive all messages: " + MSG_COUNT);
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testPrefetchedMessagesAreNotConsumedOnConsumerClose() throws Exception {
       final int NUM_MESSAGES = 10;
 
@@ -708,50 +563,48 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       }
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testMessagesReceivedInParallel() throws Throwable {
       final int numMessages = 50000;
       long time = System.currentTimeMillis();
 
       final ArrayList<Throwable> exceptions = new ArrayList<>();
 
-      Thread t = new Thread(new Runnable() {
-         @Override
-         public void run() {
-            Connection connectionConsumer = null;
-            try {
-               connectionConsumer = createConnection();
-               connectionConsumer.start();
-               Session sessionConsumer = connectionConsumer.createSession(false, Session.AUTO_ACKNOWLEDGE);
-               final javax.jms.Queue queue = sessionConsumer.createQueue(getQueueName());
-               final MessageConsumer consumer = sessionConsumer.createConsumer(queue);
+      Thread t = new Thread(() -> {
+         Connection connectionConsumer = null;
+         try {
+            connectionConsumer = createConnection();
+            connectionConsumer.start();
+            Session sessionConsumer = connectionConsumer.createSession(false, Session.AUTO_ACKNOWLEDGE);
+            final javax.jms.Queue queue = sessionConsumer.createQueue(getQueueName());
+            final MessageConsumer consumer = sessionConsumer.createConsumer(queue);
 
-               long n = 0;
-               int count = numMessages;
-               while (count > 0) {
-                  try {
-                     if (++n % 1000 == 0) {
-                        logger.debug("received {} messages", n);
-                     }
-
-                     Message m = consumer.receive(5000);
-                     Assert.assertNotNull("Could not receive message count=" + count + " on consumer", m);
-                     count--;
-                  } catch (JMSException e) {
-                     e.printStackTrace();
-                     break;
-                  }
-               }
-            } catch (Throwable e) {
-               exceptions.add(e);
-               e.printStackTrace();
-            } finally {
+            long n = 0;
+            int count = numMessages;
+            while (count > 0) {
                try {
-                  connectionConsumer.close();
-               } catch (Throwable ignored) {
-                  // NO OP
+                  if (++n % 1000 == 0) {
+                     logger.debug("received {} messages", n);
+                  }
+
+                  Message m = consumer.receive(5000);
+                  assertNotNull(m, "Could not receive message count=" + count + " on consumer");
+                  count--;
+               } catch (JMSException e) {
+                  e.printStackTrace();
+                  break;
                }
             }
+         } catch (Throwable e) {
+            exceptions.add(e);
+            e.printStackTrace();
+         } finally {
+            try {
+               connectionConsumer.close();
+            } catch (Throwable ignored) {
+               // NO OP
+            }
          }
       });
 
@@ -790,7 +643,8 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       logger.debug("{} messages per second", ((int) messagesPerSecond));
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testClientAckMessages() throws Exception {
       final int numMessages = 10;
 
@@ -821,11 +675,11 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
 
          for (int i = 0; i < numMessages; i++) {
             Message msg = consumer.receive(5000);
-            Assert.assertNotNull("" + i, msg);
-            Assert.assertTrue("" + msg, msg instanceof TextMessage);
+            assertNotNull(msg, "" + i);
+            assertTrue(msg instanceof TextMessage, "" + msg);
             String text = ((TextMessage) msg).getText();
             // System.out.println("text = " + text);
-            Assert.assertEquals(text, "msg:" + i);
+            assertEquals(text, "msg:" + i);
             msg.acknowledge();
          }
 
@@ -838,7 +692,8 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       }
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testTimedOutWaitingForWriteLogOnConsumer() throws Throwable {
       String name = "exampleQueue1";
       // disable auto-delete as it causes thrashing during the test
@@ -863,7 +718,7 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
             session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
             queue = session.createQueue(name);
             MessageConsumer c = session.createConsumer(queue);
-            Assert.assertNotNull(c.receive(1000));
+            assertNotNull(c.receive(1000));
             session.close();
          }
 
@@ -871,7 +726,7 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
          queue = session.createQueue(name);
          MessageConsumer c = session.createConsumer(queue);
          for (int i = 0; i < numMessages; i++) {
-            Assert.assertNull(c.receive(1));
+            assertNull(c.receive(1));
          }
          producer.close();
          session.close();
@@ -907,7 +762,8 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
       assertFalse(failedToSubscribe.get());
    }
 
-   @Test(timeout = 30000)
+   @Test
+   @Timeout(30)
    public void testBrokerRestartAMQPProducerAMQPConsumer() throws Exception {
       Connection connection = createFailoverConnection(); //AMQP
       Connection connection2 = createFailoverConnection(); //AMQP
@@ -934,8 +790,8 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
 
          Message received = consumer2.receive(100);
 
-         assertNotNull("Should have received a message by now.", received);
-         assertTrue("Should be an instance of TextMessage", received instanceof TextMessage);
+         assertNotNull(received, "Should have received a message by now.");
+         assertTrue(received instanceof TextMessage, "Should be an instance of TextMessage");
          assertEquals(DeliveryMode.PERSISTENT, received.getJMSDeliveryMode());
 
 
@@ -950,8 +806,8 @@ public class JMSMessageConsumerTest extends JMSClientTestSupport {
 
          Message received2 = consumer2.receive(100);
 
-         assertNotNull("Should have received a message by now.", received2);
-         assertTrue("Should be an instance of TextMessage", received2 instanceof TextMessage);
+         assertNotNull(received2, "Should have received a message by now.");
+         assertTrue(received2 instanceof TextMessage, "Should be an instance of TextMessage");
          assertEquals(DeliveryMode.PERSISTENT, received2.getJMSDeliveryMode());
 
 
