@@ -16,6 +16,13 @@
  */
 package org.apache.activemq.artemis.tests.integration.amqp.connect;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.MessageConsumer;
@@ -54,10 +61,9 @@ import org.apache.activemq.transport.amqp.client.AmqpMessage;
 import org.apache.activemq.transport.amqp.client.AmqpReceiver;
 import org.apache.activemq.transport.amqp.client.AmqpSender;
 import org.apache.activemq.transport.amqp.client.AmqpSession;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import java.lang.invoke.MethodHandles;
@@ -69,30 +75,30 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
    ActiveMQServer server_2;
    private AssertionLoggerHandler loggerHandler;
 
-   @After
+   @AfterEach
    public void stopServer1() throws Exception {
       if (server != null) {
          server.stop();
       }
    }
 
-   @After
+   @AfterEach
    public void stopServer2() throws Exception {
       if (server_2 != null) {
          server_2.stop();
       }
    }
 
-   @Before
+   @BeforeEach
    public void startLogging() {
       loggerHandler = new AssertionLoggerHandler();
 
    }
 
-   @After
+   @AfterEach
    public void stopLogging() throws Exception {
       try {
-         Assert.assertFalse(loggerHandler.findText("AMQ222214"));
+         assertFalse(loggerHandler.findText("AMQ222214"));
       } finally {
          loggerHandler.close();
       }
@@ -125,13 +131,13 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo("sometest").setAutoCreated(false));
-      server_2.createQueue(new QueueConfiguration("sometest").setDurable(true));
+      server_2.createQueue(QueueConfiguration.of("sometest").setDurable(true));
 
       Wait.assertTrue(() -> server_2.locateQueue("sometest") != null);
       Wait.assertTrue(() -> server.locateQueue("sometest") != null);
 
       server.addAddressInfo(new AddressInfo("OnServer1").setAutoCreated(false));
-      server.createQueue(new QueueConfiguration("OnServer1").setDurable(true));
+      server.createQueue(QueueConfiguration.of("OnServer1").setDurable(true));
 
       Wait.assertTrue(() -> server.locateQueue("OnServer1") != null);
       Wait.assertTrue("Sync is not working on the way back", () -> server_2.locateQueue("OnServer1") != null, 2000);
@@ -141,8 +147,8 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
 
       for (int i = 0; i < 10; i++) {
          final int queueID = i;
-         server_2.createQueue(new QueueConfiguration("test2_" + i).setDurable(true));
-         server.createQueue(new QueueConfiguration("test1_" + i).setDurable(true));
+         server_2.createQueue(QueueConfiguration.of("test2_" + i).setDurable(true));
+         server.createQueue(QueueConfiguration.of("test1_" + i).setDurable(true));
          Wait.assertTrue(() -> server.locateQueue("test2_" + queueID) != null);
          Wait.assertTrue(() -> server.locateQueue("test1_" + queueID) != null);
          Wait.assertTrue(() -> server_2.locateQueue("test2_" + queueID) != null);
@@ -176,7 +182,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo(getQueueName()).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
 
       Wait.assertTrue(() -> server_2.locateQueue(getQueueName()) != null);
       Wait.assertTrue(() -> server.locateQueue(getQueueName()) != null);
@@ -204,8 +210,8 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
 
       org.apache.activemq.artemis.core.server.Queue queueOnServer1 = server.locateQueue(getQueueName());
       org.apache.activemq.artemis.core.server.Queue queueOnServer2 = server_2.locateQueue(getQueueName());
-      Assert.assertNotNull(queueOnServer1);
-      Assert.assertNotNull(queueOnServer2);
+      assertNotNull(queueOnServer1);
+      assertNotNull(queueOnServer2);
 
       Wait.assertEquals(1, queueOnServer1::getMessageCount);
       Wait.assertEquals(1, queueOnServer2::getMessageCount);
@@ -234,7 +240,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
    private org.apache.activemq.artemis.core.server.Queue locateQueueWithWait(ActiveMQServer server, String queueName) throws Exception {
       Wait.assertTrue(() -> server.locateQueue(queueName) != null);
       org.apache.activemq.artemis.core.server.Queue queue = server.locateQueue(queueName);
-      Assert.assertNotNull(queue);
+      assertNotNull(queue);
       return queue;
    }
 
@@ -256,10 +262,10 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
          server.getConfiguration().addAMQPConnection(amqpConnection);
       }
 
-      server.getConfiguration().addAddressSetting("#", new AddressSettings().setExpiryAddress(SimpleString.toSimpleString("expiryQueue")));
+      server.getConfiguration().addAddressSetting("#", new AddressSettings().setExpiryAddress(SimpleString.of("expiryQueue")));
 
       server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName("expiryQueue"));
-      server.getConfiguration().addQueueConfiguration(new QueueConfiguration("expiryQueue").setRoutingType(RoutingType.ANYCAST));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of("expiryQueue").setRoutingType(RoutingType.ANYCAST));
       if (!useReaper) {
          server.getConfiguration().setMessageExpiryScanPeriod(-1);
       }
@@ -269,7 +275,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2 = createServer(AMQP_PORT_2, false);
 
       server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName("expiryQueue"));
-      server.getConfiguration().addQueueConfiguration(new QueueConfiguration("expiryQueue").setRoutingType(RoutingType.ANYCAST));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of("expiryQueue").setRoutingType(RoutingType.ANYCAST));
       if (!useReaper) {
          server_2.getConfiguration().setMessageExpiryScanPeriod(-1);
       }
@@ -282,7 +288,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
          server_2.getConfiguration().addAMQPConnection(amqpConnection);
       }
 
-      server_2.getConfiguration().addAddressSetting("#", new AddressSettings().setExpiryAddress(SimpleString.toSimpleString("expiryQueue")));
+      server_2.getConfiguration().addAddressSetting("#", new AddressSettings().setExpiryAddress(SimpleString.of("expiryQueue")));
 
       server_2.start();
 
@@ -292,7 +298,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       org.apache.activemq.artemis.core.server.Queue expiry2 = locateQueueWithWait(server_2, "expiryQueue");
 
       server_2.addAddressInfo(new AddressInfo(getQueueName()).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
 
       org.apache.activemq.artemis.core.server.Queue queueOnServer1 = locateQueueWithWait(server, getQueueName());
       org.apache.activemq.artemis.core.server.Queue queueOnServer2 = locateQueueWithWait(server_2, getQueueName());
@@ -360,10 +366,10 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
          server.getConfiguration().addAMQPConnection(amqpConnection);
       }
 
-      server.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.toSimpleString("deadLetterQueue")).setMaxDeliveryAttempts(2));
+      server.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.of("deadLetterQueue")).setMaxDeliveryAttempts(2));
 
       server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName("deadLetterQueue"));
-      server.getConfiguration().addQueueConfiguration(new QueueConfiguration("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
       server.getConfiguration().setMessageExpiryScanPeriod(-1);
 
       server.start();
@@ -371,7 +377,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2 = createServer(AMQP_PORT_2, false);
 
       server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName("deadLetterQueue"));
-      server.getConfiguration().addQueueConfiguration(new QueueConfiguration("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
       server_2.getConfiguration().setMessageExpiryScanPeriod(-1);
 
       server_2.setIdentity("Server2");
@@ -382,7 +388,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
          server_2.getConfiguration().addAMQPConnection(amqpConnection);
       }
 
-      server_2.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.toSimpleString("deadLetterQueue")).setMaxDeliveryAttempts(2));
+      server_2.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.of("deadLetterQueue")).setMaxDeliveryAttempts(2));
 
       server_2.start();
 
@@ -392,7 +398,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       org.apache.activemq.artemis.core.server.Queue dlq2 = locateQueueWithWait(server_2, "deadLetterQueue");
 
       server_2.addAddressInfo(new AddressInfo(getQueueName()).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
 
       org.apache.activemq.artemis.core.server.Queue queueOnServer1 = locateQueueWithWait(server, getQueueName());
       org.apache.activemq.artemis.core.server.Queue queueOnServer2 = locateQueueWithWait(server_2, getQueueName());
@@ -418,11 +424,11 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
 
       for (int i = 0; i < 2; i++) {
          TextMessage messageToCancel = (TextMessage) consumer1.receive(1000);
-         Assert.assertNotNull(messageToCancel);
+         assertNotNull(messageToCancel);
          session1.rollback();
       }
 
-      Assert.assertNull(consumer1.receiveNoWait());
+      assertNull(consumer1.receiveNoWait());
 
       Wait.assertEquals(0L, queueOnServer1::getMessageCount, 1000, 100);
       Wait.assertEquals(0L, queueOnServer2::getMessageCount, 1000, 100);
@@ -449,7 +455,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
 
          @Override
          public SimpleString getFilterString() {
-            return SimpleString.toSimpleString("Test");
+            return SimpleString.of("Test");
          }
       });
 
@@ -467,6 +473,67 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
    }
 
 
+   @Test
+   public void testCreateInternalQueue() throws Exception {
+      server.setIdentity("Server1");
+      {
+         AMQPBrokerConnectConfiguration amqpConnection = new AMQPBrokerConnectConfiguration("to_2", "tcp://localhost:" + AMQP_PORT_2).setReconnectAttempts(3).setRetryInterval(100);
+         amqpConnection.addElement(new AMQPMirrorBrokerConnectionElement().setDurable(true));
+         server.getConfiguration().addAMQPConnection(amqpConnection);
+      }
+
+      server.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.of("deadLetterQueue")).setMaxDeliveryAttempts(2));
+
+      server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName("deadLetterQueue"));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
+      server.getConfiguration().setMessageExpiryScanPeriod(-1);
+
+      server.start();
+
+      server_2 = createServer(AMQP_PORT_2, false);
+
+      server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName("deadLetterQueue"));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
+      server_2.getConfiguration().setMessageExpiryScanPeriod(-1);
+
+      server_2.setIdentity("Server2");
+
+      {
+         AMQPBrokerConnectConfiguration amqpConnection = new AMQPBrokerConnectConfiguration("to_1", "tcp://localhost:" + AMQP_PORT).setReconnectAttempts(-1).setRetryInterval(100);
+         amqpConnection.addElement(new AMQPMirrorBrokerConnectionElement().setDurable(true));
+         server_2.getConfiguration().addAMQPConnection(amqpConnection);
+      }
+
+      server_2.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.of("deadLetterQueue")).setMaxDeliveryAttempts(2));
+
+      server_2.start();
+
+      org.apache.activemq.artemis.core.server.Queue to1 = locateQueueWithWait(server_2, "$ACTIVEMQ_ARTEMIS_MIRROR_to_1");
+      assertNotNull(to1);
+
+      long messagesAddedOnS2 = to1.getMessagesAdded();
+
+      String internalQueueName = getQueueName() + "Internal";
+
+      server.addAddressInfo(new AddressInfo(internalQueueName).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST).setInternal(true));
+      server.createQueue(QueueConfiguration.of(internalQueueName).setDurable(true).setRoutingType(RoutingType.ANYCAST).setInternal(true));
+
+      server.addAddressInfo(new AddressInfo(getQueueName()).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST));
+      server.createQueue(QueueConfiguration.of(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+
+      Wait.assertTrue(() -> server_2.locateQueue(getQueueName()) != null, 5000);
+      assertTrue(server_2.getAddressInfo(SimpleString.of(internalQueueName)) == null);
+      assertTrue(server_2.locateQueue(internalQueueName) == null);
+
+      assertEquals(messagesAddedOnS2, to1.getMessagesAdded());
+
+      server_2.stop();
+      server.stop();
+   }
+
+
+
+
    @Test
    public void testLVQ() throws Exception {
       AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler();
@@ -479,15 +546,15 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
          server.getConfiguration().addAMQPConnection(amqpConnection);
       }
 
-      server.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.toSimpleString("deadLetterQueue")).setMaxDeliveryAttempts(2));
+      server.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.of("deadLetterQueue")).setMaxDeliveryAttempts(2));
 
       server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName("deadLetterQueue"));
-      server.getConfiguration().addQueueConfiguration(new QueueConfiguration("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
 
       String lvqName = "testLVQ_" + RandomUtil.randomString();
 
       server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName(lvqName));
-      server.getConfiguration().addQueueConfiguration(new QueueConfiguration(lvqName).setRoutingType(RoutingType.ANYCAST).setLastValue(true).setLastValueKey("KEY"));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of(lvqName).setRoutingType(RoutingType.ANYCAST).setLastValue(true).setLastValueKey("KEY"));
       server.getConfiguration().setMessageExpiryScanPeriod(-1);
 
       server.start();
@@ -495,7 +562,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2 = createServer(AMQP_PORT_2, false);
 
       server.getConfiguration().addAddressConfiguration(new CoreAddressConfiguration().setName("deadLetterQueue"));
-      server.getConfiguration().addQueueConfiguration(new QueueConfiguration("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
+      server.getConfiguration().addQueueConfiguration(QueueConfiguration.of("deadLetterQueue").setRoutingType(RoutingType.ANYCAST));
       server_2.getConfiguration().setMessageExpiryScanPeriod(-1);
 
       server_2.setIdentity("Server2");
@@ -506,44 +573,42 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
          server_2.getConfiguration().addAMQPConnection(amqpConnection);
       }
 
-      server_2.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.toSimpleString("deadLetterQueue")).setMaxDeliveryAttempts(2));
+      server_2.getConfiguration().addAddressSetting("#", new AddressSettings().setDeadLetterAddress(SimpleString.of("deadLetterQueue")).setMaxDeliveryAttempts(2));
       server_2.start();
 
       org.apache.activemq.artemis.core.server.Queue lvqQueue1 = locateQueueWithWait(server, lvqName);
       org.apache.activemq.artemis.core.server.Queue lvqQueue2 = locateQueueWithWait(server, lvqName);
 
-      Assert.assertTrue(lvqQueue1.isLastValue());
-      Assert.assertTrue(lvqQueue2.isLastValue());
-      Assert.assertTrue(lvqQueue1 instanceof LastValueQueue);
-      Assert.assertTrue(lvqQueue2 instanceof LastValueQueue);
-      Assert.assertEquals("KEY", lvqQueue1.getQueueConfiguration().getLastValueKey().toString());
-      Assert.assertEquals("KEY", lvqQueue2.getQueueConfiguration().getLastValueKey().toString());
+      assertTrue(lvqQueue1.isLastValue());
+      assertTrue(lvqQueue2.isLastValue());
+      assertTrue(lvqQueue1 instanceof LastValueQueue);
+      assertTrue(lvqQueue2 instanceof LastValueQueue);
+      assertEquals("KEY", lvqQueue1.getQueueConfiguration().getLastValueKey().toString());
+      assertEquals("KEY", lvqQueue2.getQueueConfiguration().getLastValueKey().toString());
 
       ConnectionFactory cf1 = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:" + AMQP_PORT);
-      Connection connection1 = cf1.createConnection();
-      Session session1 = connection1.createSession(false, Session.AUTO_ACKNOWLEDGE);
-      connection1.start();
-
-      Queue queue = session1.createQueue(lvqName);
-
-      MessageProducer producerServer1 = session1.createProducer(queue);
-
-      for (int i = 0; i < 1000; i++) {
-         TextMessage message = session1.createTextMessage("test");
-         message.setIntProperty("i", 0);
-         message.setStringProperty("KEY", "" + (i % 10));
-         producerServer1.send(message);
+      try (Connection connection1 = cf1.createConnection()) {
+         Session session1 = connection1.createSession(false, Session.AUTO_ACKNOWLEDGE);
+         Queue queue = session1.createQueue(lvqName);
+         MessageProducer producerServer1 = session1.createProducer(queue);
+         connection1.start();
+         for (int i = 0; i < 1000; i++) {
+            TextMessage message = session1.createTextMessage("test");
+            message.setIntProperty("i", 0);
+            message.setStringProperty("KEY", "" + (i % 10));
+            producerServer1.send(message);
+         }
       }
+      assertFalse(loggerHandler.findText("AMQ222214"));
 
       Wait.assertEquals(10L, lvqQueue1::getMessageCount, 2000, 100);
       Wait.assertEquals(10L, lvqQueue2::getMessageCount, 2000, 100);
 
-      connection1.close();
 
       server_2.stop();
       server.stop();
 
-      Assert.assertFalse(loggerHandler.findText("AMQ222153"));
+      assertFalse(loggerHandler.findText("AMQ222153"));
    }
 
 
@@ -570,7 +635,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo(getQueueName()).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
 
       Wait.assertTrue(() -> server_2.locateQueue(getQueueName()) != null);
       Wait.assertTrue(() -> server.locateQueue(getQueueName()) != null);
@@ -600,8 +665,8 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
 
       org.apache.activemq.artemis.core.server.Queue queueOnServer1 = server.locateQueue(getQueueName());
       org.apache.activemq.artemis.core.server.Queue queueOnServer2 = server_2.locateQueue(getQueueName());
-      Assert.assertNotNull(queueOnServer1);
-      Assert.assertNotNull(queueOnServer2);
+      assertNotNull(queueOnServer1);
+      assertNotNull(queueOnServer2);
 
       Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer1::getMessageCount);
       Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer2::getMessageCount);
@@ -625,9 +690,9 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       for (int i = 0; i < NUMBER_OF_MESSAGES * 2; i++) {
          TextMessage message = (TextMessage) consumerOn1.receive(5000);
          logger.debug("### Client acking message({}) on server 1, a message that was original sent on {} text = {}", i, message.getStringProperty("server"), message.getText());
-         Assert.assertNotNull(message);
-         Assert.assertEquals(i, message.getIntProperty("i"));
-         Assert.assertEquals("test " + i, message.getText());
+         assertNotNull(message);
+         assertEquals(i, message.getIntProperty("i"));
+         assertEquals("test " + i, message.getText());
          session1.commit();
       }
 
@@ -641,23 +706,23 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
 
       if (logger.isDebugEnabled() && !bothConsumed) {
          debugData();
-         Assert.fail("q1 = " + queueOnServer1.getMessageCount() + ", q2 = " + queueOnServer2.getMessageCount());
+         fail("q1 = " + queueOnServer1.getMessageCount() + ", q2 = " + queueOnServer2.getMessageCount());
       }
 
-      Assert.assertEquals(0, queueOnServer1.getMessageCount());
-      Assert.assertEquals(0, queueOnServer2.getConsumerCount());
+      assertEquals(0, queueOnServer1.getMessageCount());
+      assertEquals(0, queueOnServer2.getConsumerCount());
 
       System.out.println("Queue on Server 1 = " + queueOnServer1.getMessageCount());
       System.out.println("Queue on Server 2 = " + queueOnServer2.getMessageCount());
 
-      Assert.assertEquals(0, queueOnServer1.getDeliveringCount());
-      Assert.assertEquals(0, queueOnServer2.getDeliveringCount());
-      Assert.assertEquals(0, queueOnServer1.getDurableDeliveringCount());
-      Assert.assertEquals(0, queueOnServer2.getDurableDeliveringCount());
-      Assert.assertEquals(0, queueOnServer1.getDurableDeliveringSize());
-      Assert.assertEquals(0, queueOnServer2.getDurableDeliveringSize());
-      Assert.assertEquals(0, queueOnServer1.getDeliveringSize());
-      Assert.assertEquals(0, queueOnServer2.getDeliveringSize());
+      assertEquals(0, queueOnServer1.getDeliveringCount());
+      assertEquals(0, queueOnServer2.getDeliveringCount());
+      assertEquals(0, queueOnServer1.getDurableDeliveringCount());
+      assertEquals(0, queueOnServer2.getDurableDeliveringCount());
+      assertEquals(0, queueOnServer1.getDurableDeliveringSize());
+      assertEquals(0, queueOnServer2.getDurableDeliveringSize());
+      assertEquals(0, queueOnServer1.getDeliveringSize());
+      assertEquals(0, queueOnServer2.getDeliveringSize());
 
       server_2.stop();
       server.stop();
@@ -688,10 +753,10 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo(getQueueName()).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
 
       Wait.assertTrue(() -> server_2.locateQueue(getQueueName()) != null);
-      Wait.assertTrue(() -> server.locateQueue(getQueueName()) != null);
+      Wait.assertTrue(() -> server.locateQueue(getQueueName()) != null, 5000);
 
       ConnectionFactory cf1 = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:" + AMQP_PORT);
       Connection connection1 = cf1.createConnection();
@@ -718,36 +783,36 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
 
       org.apache.activemq.artemis.core.server.Queue queueOnServer1 = server.locateQueue(getQueueName());
       org.apache.activemq.artemis.core.server.Queue queueOnServer2 = server_2.locateQueue(getQueueName());
-      Assert.assertNotNull(queueOnServer1);
-      Assert.assertNotNull(queueOnServer2);
+      assertNotNull(queueOnServer1);
+      assertNotNull(queueOnServer2);
 
       Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer1::getMessageCount);
       Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer2::getMessageCount);
 
-      Assert.assertEquals(0, queueOnServer1.getDeliveringSize());
-      Assert.assertEquals(0, queueOnServer2.getDeliveringSize());
+      assertEquals(0, queueOnServer1.getDeliveringSize());
+      assertEquals(0, queueOnServer2.getDeliveringSize());
 
       MessageConsumer consumerOn1 = session1.createConsumer(queue);
       for (int i = 0; i < NUMBER_OF_MESSAGES; i++) {
          TextMessage message = (TextMessage) consumerOn1.receive(5000);
          logger.debug("### Client acking message({}) on server 1, a message that was original sent on {} text = {}", i, message.getStringProperty("server"), message.getText());
-         Assert.assertNotNull(message);
-         Assert.assertEquals(i, message.getIntProperty("i"));
-         Assert.assertEquals("test " + i, message.getText());
+         assertNotNull(message);
+         assertEquals(i, message.getIntProperty("i"));
+         assertEquals("test " + i, message.getText());
          session1.commit();
          int fi = i;
       }
 
       Wait.assertEquals(0L, queueOnServer1::getMessageCount, 2000, 100);
       Wait.assertEquals(0L, queueOnServer2::getMessageCount, 2000, 100);
-      Assert.assertEquals(0, queueOnServer1.getDeliveringCount());
-      Assert.assertEquals(0, queueOnServer2.getDeliveringCount());
-      Assert.assertEquals(0, queueOnServer1.getDurableDeliveringCount());
-      Assert.assertEquals(0, queueOnServer2.getDurableDeliveringCount());
-      Assert.assertEquals(0, queueOnServer1.getDurableDeliveringSize());
-      Assert.assertEquals(0, queueOnServer2.getDurableDeliveringSize());
-      Assert.assertEquals(0, queueOnServer1.getDeliveringSize());
-      Assert.assertEquals(0, queueOnServer2.getDeliveringSize());
+      assertEquals(0, queueOnServer1.getDeliveringCount());
+      assertEquals(0, queueOnServer2.getDeliveringCount());
+      assertEquals(0, queueOnServer1.getDurableDeliveringCount());
+      assertEquals(0, queueOnServer2.getDurableDeliveringCount());
+      assertEquals(0, queueOnServer1.getDurableDeliveringSize());
+      assertEquals(0, queueOnServer2.getDurableDeliveringSize());
+      assertEquals(0, queueOnServer1.getDeliveringSize());
+      assertEquals(0, queueOnServer2.getDeliveringSize());
 
       server_2.stop();
       server.stop();
@@ -797,7 +862,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo(getQueueName()).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setDurable(true).setRoutingType(RoutingType.ANYCAST));
 
       Wait.assertTrue(() -> server_2.locateQueue(getQueueName()) != null);
       Wait.assertTrue(() -> server.locateQueue(getQueueName()) != null);
@@ -824,8 +889,8 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
 
       org.apache.activemq.artemis.core.server.Queue queueOnServer1 = server.locateQueue(getQueueName());
       org.apache.activemq.artemis.core.server.Queue queueOnServer2 = server_2.locateQueue(getQueueName());
-      Assert.assertNotNull(queueOnServer1);
-      Assert.assertNotNull(queueOnServer2);
+      assertNotNull(queueOnServer1);
+      assertNotNull(queueOnServer2);
 
       Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer1::getMessageCount);
       Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer2::getMessageCount);
@@ -844,9 +909,9 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       consumerOn1.flow(NUMBER_OF_MESSAGES * 2 + 1);
       for (int i = 0; i < NUMBER_OF_MESSAGES * 2; i++) {
          AmqpMessage message = consumerOn1.receive(5, TimeUnit.SECONDS);
-         Assert.assertNotNull(message);
+         assertNotNull(message);
          message.accept();
-         Assert.assertEquals(i, (int) message.getApplicationProperty("i"));
+         assertEquals(i, (int) message.getApplicationProperty("i"));
       }
 
       Wait.assertEquals(0, queueOnServer1::getMessageCount);
@@ -884,7 +949,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo(queueName).setAutoCreated(false).addRoutingType(RoutingType.ANYCAST));
-      server_2.createQueue(new QueueConfiguration(queueName).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+      server_2.createQueue(QueueConfiguration.of(queueName).setDurable(true).setRoutingType(RoutingType.ANYCAST));
 
       Wait.assertTrue(() -> server_2.locateQueue(queueName) != null);
       Wait.assertTrue(() -> server.locateQueue(queueName) != null);
@@ -917,8 +982,8 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
          MessageConsumer consumer = session.createConsumer(queue);
          connection.start();
          TextMessage message = (TextMessage)consumer.receive(5000);
-         Assert.assertNotNull(message);
-         Assert.assertEquals(bigString, message.getText());
+         assertNotNull(message);
+         assertEquals(bigString, message.getText());
          Wait.assertEquals(0, () -> getNumberOfFiles(server_2.getConfiguration().getLargeMessagesLocation()), 5000, 100);
       }
 
@@ -932,7 +997,7 @@ public class BrokerInSyncTest extends AmqpClientTestSupport {
          MessageConsumer consumer = session.createConsumer(queue);
          connection.start();
          TextMessage message = (TextMessage)consumer.receiveNoWait();
-         Assert.assertNull(message);
+         assertNull(message);
          server.stop();
          server_2.stop();
          Wait.assertEquals(0, () -> getNumberOfFiles(server.getConfiguration().getLargeMessagesLocation()), 1000, 100);
