@@ -16,6 +16,10 @@
  */
 package org.apache.activemq.artemis.tests.integration.mqtt;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.util.concurrent.TimeUnit;
 
 import org.apache.activemq.artemis.api.core.QueueConfiguration;
@@ -37,7 +41,7 @@ import org.fusesource.mqtt.client.MQTT;
 import org.fusesource.mqtt.client.Message;
 import org.fusesource.mqtt.client.QoS;
 import org.fusesource.mqtt.client.Topic;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
 
@@ -68,14 +72,14 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          Topic[] topics = {new Topic(ANYCAST_TOPIC, QoS.AT_MOST_ONCE)};
          subConnection1 = retrieveMQTTConnection("tcp://localhost:61616", subClientId);
 
-         Wait.assertEquals(1, locateMQTTPM(servers[0]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[0]).getStateManager().getConnectedClients()::size);
 
          subConnection2 = retrieveMQTTConnection("tcp://localhost:61617", subClientId);
          pubConnection = retrieveMQTTConnection("tcp://localhost:61616", pubClientId);
 
          //Waiting for the first sub connection be closed
          assertTrue(waitConnectionClosed(subConnection1));
-         Wait.assertEquals(1, locateMQTTPM(servers[1]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[1]).getStateManager().getConnectedClients()::size);
          subConnection1 = null;
          subConnection2.subscribe(topics);
 
@@ -258,14 +262,14 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          Topic[] topics = {new Topic(MULTICAST_TOPIC, QoS.AT_MOST_ONCE)};
          subConnection1 = retrieveMQTTConnection("tcp://localhost:61616", subClientId);
 
-         Wait.assertEquals(1, locateMQTTPM(servers[0]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[0]).getStateManager().getConnectedClients()::size);
 
          subConnection2 = retrieveMQTTConnection("tcp://localhost:61617", subClientId);
          pubConnection = retrieveMQTTConnection("tcp://localhost:61616", pubClientId);
 
          //Waiting for the first sub connection be closed
          assertTrue(waitConnectionClosed(subConnection1));
-         Wait.assertEquals(1, locateMQTTPM(servers[1]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[1]).getStateManager().getConnectedClients()::size);
          subConnection1 = null;
 
 
@@ -456,14 +460,14 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          Topic[] topics = {new Topic(ANYCAST_TOPIC, QoS.AT_MOST_ONCE)};
          subConnection1 = retrieveMQTTConnection("tcp://localhost:61616", subClientId);
 
-         Wait.assertEquals(1, locateMQTTPM(servers[0]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[0]).getStateManager().getConnectedClients()::size);
 
          subConnection2 = retrieveMQTTConnection("tcp://localhost:61617", subClientId);
          pubConnection = retrieveMQTTConnection("tcp://localhost:61616", pubClientId);
 
          //Waiting for the first sub connection be closed
          assertTrue(waitConnectionClosed(subConnection1));
-         Wait.assertEquals(1, locateMQTTPM(servers[1]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[1]).getStateManager().getConnectedClients()::size);
          subConnection1 = null;
 
          subConnection2.subscribe(topics);
@@ -483,17 +487,8 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          pubConnection.publish("anycast/test/1/some/la", payload2.getBytes(), QoS.AT_MOST_ONCE, false);
          pubConnection.publish("anycast/test/1/some/la", payload3.getBytes(), QoS.AT_MOST_ONCE, false);
 
-         Message message1 = subConnection2.receive(5, TimeUnit.SECONDS);
-         message1.ack();
-         Message message2 = subConnection2.receive(5, TimeUnit.SECONDS);
-         message2.ack();
-         Message message3 = subConnection2.receive(5, TimeUnit.SECONDS);
-         message3.ack();
-
-         assertEquals(payload1, new String(message1.getPayload()));
-         assertEquals(payload2, new String(message2.getPayload()));
-         assertEquals(payload3, new String(message3.getPayload()));
-
+         // pub queue gets auto created, the routing type set on the message to reflect that and the
+         // message does not get routed to the sub queue that has anycast
          subConnection2.unsubscribe(new String[]{ANYCAST_TOPIC});
 
          waitForBindings(0, ANYCAST_TOPIC, 1, 0, true);
@@ -506,13 +501,6 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          pubConnection.publish("anycast/test/1/some/la", payload2.getBytes(), QoS.AT_MOST_ONCE, false);
          pubConnection.publish("anycast/test/1/some/la", payload3.getBytes(), QoS.AT_MOST_ONCE, false);
 
-         Message message11 = subConnection2.receive(100, TimeUnit.MILLISECONDS);
-         assertNull(message11);
-         Message message21 = subConnection2.receive(100, TimeUnit.MILLISECONDS);
-         assertNull(message21);
-         Message message31 = subConnection2.receive(100, TimeUnit.MILLISECONDS);
-         assertNull(message31);
-
       } finally {
          String[] topics = new String[]{ANYCAST_TOPIC};
          if (subConnection1 != null && subConnection1.isConnected()) {
@@ -576,20 +564,8 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          connection1.publish("anycast/test/1/some/la", payload3.getBytes(), QoS.AT_MOST_ONCE, false);
 
 
-         Message message1 = connection1.receive(5, TimeUnit.SECONDS);
-         assertNotNull(message1);
-         message1.ack();
-         Message message2 = connection2.receive(5, TimeUnit.SECONDS);
-         assertNotNull(message2);
-         message2.ack();
-         Message message3 = connection1.receive(5, TimeUnit.SECONDS);
-         assertNotNull(message3);
-         message3.ack();
-
-         assertEquals(payload1, new String(message1.getPayload()));
-         assertEquals(payload2, new String(message2.getPayload()));
-         assertEquals(payload3, new String(message3.getPayload()));
-
+         // the pub queue is auto created and the message multicast routing type won't match the anycast sub queue
+         // so nothing gets routed to this queue
 
          connection2.unsubscribe(new String[]{ANYCAST_TOPIC});
 
@@ -603,24 +579,6 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          connection1.publish("anycast/test/1/some/la", payload2.getBytes(), QoS.AT_MOST_ONCE, false);
          connection1.publish("anycast/test/1/some/la", payload3.getBytes(), QoS.AT_MOST_ONCE, false);
 
-         Message message11 = connection1.receive(5, TimeUnit.SECONDS);
-         assertNotNull(message11);
-         message11.ack();
-         Message message21 = connection1.receive(5, TimeUnit.SECONDS);
-         assertNotNull(message21);
-         message21.ack();
-         Message message31 = connection1.receive(5, TimeUnit.SECONDS);
-         assertNotNull(message31);
-         message31.ack();
-
-
-         String message11String = new String(message11.getPayload());
-         String message21String = new String(message21.getPayload());
-         String message31String = new String(message31.getPayload());
-         assertTrue(payload1.equals(message11String) || payload1.equals(message21String) || payload1.equals(message31String) );
-         assertTrue(payload2.equals(message11String) || payload2.equals(message21String) || payload2.equals(message31String) );
-         assertTrue(payload3.equals(message11String) || payload3.equals(message21String) || payload3.equals(message31String) );
-
       } finally {
          String[] topics = new String[]{ANYCAST_TOPIC};
          if (connection1 != null && connection1.isConnected()) {
@@ -668,7 +626,7 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          Thread.sleep(1000);
          Topic[] topics = {new Topic(MULTICAST_TOPIC, QoS.AT_MOST_ONCE)};
          subConnection1 = retrieveMQTTConnection("tcp://localhost:61616", subClientId);
-         Wait.assertEquals(1, locateMQTTPM(servers[0]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[0]).getStateManager().getConnectedClients()::size);
          subConnection2 = retrieveMQTTConnection("tcp://localhost:61617", subClientId);
          pubConnection = retrieveMQTTConnection("tcp://localhost:61616", pubClientId);
 
@@ -757,9 +715,9 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          Thread.sleep(1000);
          Topic[] topics = {new Topic(MULTICAST_TOPIC, QoS.AT_MOST_ONCE)};
          connection1 = retrieveMQTTConnection("tcp://localhost:61616", clientId1);
-         Wait.assertEquals(1, locateMQTTPM(servers[0]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[0]).getStateManager().getConnectedClients()::size);
          connection2 = retrieveMQTTConnection("tcp://localhost:61617", clientId2);
-         Wait.assertEquals(1, locateMQTTPM(servers[1]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[1]).getStateManager().getConnectedClients()::size);
          // Subscribe to topics
          connection1.subscribe(topics);
 
@@ -970,7 +928,7 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          Thread.sleep(1000);
          subConnection1 = retrieveMQTTConnection("tcp://localhost:61616", subClientId);
 
-         Wait.assertEquals(1, locateMQTTPM(servers[0]).getConnectedClients()::size);
+         Wait.assertEquals(1, locateMQTTPM(servers[0]).getStateManager().getConnectedClients()::size);
 
          subConnection2 = retrieveMQTTConnection("tcp://localhost:61617", subClientId);
          pubConnection = retrieveMQTTConnection("tcp://localhost:61616", pubClientId);
@@ -1075,7 +1033,7 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
          pubConnection = retrieveMQTTConnection("tcp://localhost:61616", pubClientId);
 
          subConnection1 = retrieveMQTTConnection("tcp://localhost:61616", subClientId);
-         Wait.assertEquals(2, locateMQTTPM(servers[0]).getConnectedClients()::size);
+         Wait.assertEquals(2, locateMQTTPM(servers[0]).getStateManager().getConnectedClients()::size);
          subConnection2 = retrieveMQTTConnection("tcp://localhost:61617", subClientId);
 
          //Waiting for the first sub connection be closed
@@ -1299,11 +1257,11 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
       setupServer(0, false, isNetty());
       servers[0].getConfiguration().setWildCardConfiguration(wildcardConfiguration);
       servers[0].getConfiguration().addAddressConfiguration(coreAddressConfiguration);
-      servers[0].getConfiguration().addAddressesSetting("#", addressSettings);
+      servers[0].getConfiguration().addAddressSetting("#", addressSettings);
       setupServer(1, false, isNetty());
       servers[1].getConfiguration().setWildCardConfiguration(wildcardConfiguration);
       servers[1].getConfiguration().addAddressConfiguration(coreAddressConfiguration);
-      servers[1].getConfiguration().addAddressesSetting("#", addressSettings);
+      servers[1].getConfiguration().addAddressSetting("#", addressSettings);
 
       setupClusterConnection("cluster0", "", MessageLoadBalancingType.ON_DEMAND, 1, isNetty(), 0, 1);
       setupClusterConnection("cluster1", "", MessageLoadBalancingType.ON_DEMAND, 1, isNetty(), 1, 0);
@@ -1320,7 +1278,7 @@ public class MqttClusterRemoteSubscribeTest extends ClusterTestBase {
       CoreAddressConfiguration coreAddressConfiguration = new CoreAddressConfiguration();
       coreAddressConfiguration.addRoutingType(RoutingType.ANYCAST);
       coreAddressConfiguration.setName(TOPIC);
-      coreAddressConfiguration.addQueueConfiguration(new QueueConfiguration(TOPIC).setRoutingType(RoutingType.ANYCAST));
+      coreAddressConfiguration.addQueueConfiguration(QueueConfiguration.of(TOPIC).setRoutingType(RoutingType.ANYCAST));
       return coreAddressConfiguration;
    }
 
