@@ -16,6 +16,12 @@
  */
 package org.apache.activemq.artemis.tests.integration.persistence;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.DeliveryMode;
@@ -54,14 +60,15 @@ import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.jms.server.JMSServerManager;
 import org.apache.activemq.artemis.jms.server.impl.JMSServerManagerImpl;
+import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.activemq.artemis.tests.extensions.parameterized.Parameters;
 import org.apache.activemq.artemis.tests.unit.util.InVMContext;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.tests.util.RandomUtil;
 import org.apache.activemq.artemis.tests.util.Wait;
 import org.apache.activemq.artemis.utils.UUIDGenerator;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import java.lang.invoke.MethodHandles;
@@ -69,14 +76,14 @@ import java.lang.invoke.MethodHandles;
 /**
  * A test of the XML export/import functionality
  */
-@RunWith(value = Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class XmlImportExportTest extends ActiveMQTestBase {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    private boolean forceLongs;
 
-   @Parameterized.Parameters(name = "forceLongs={0}")
+   @Parameters(name = "forceLongs={0}")
    public static Collection getParameters() {
       return Arrays.asList(new Object[][]{{true}, {false}});
    }
@@ -102,11 +109,11 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testMessageProperties() throws Exception {
       ClientSession session = basicSetUp();
 
-      session.createQueue(new QueueConfiguration(QUEUE_NAME));
+      session.createQueue(QueueConfiguration.of(QUEUE_NAME));
 
       ClientProducer producer = session.createProducer(QUEUE_NAME);
 
@@ -134,8 +141,8 @@ public class XmlImportExportTest extends ActiveMQTestBase {
          msg.putStringProperty("myNullStringProperty", null);
          msg.putStringProperty("myNonAsciiStringProperty", international.toString());
          msg.putStringProperty("mySpecialCharacters", special);
-         msg.putStringProperty(new SimpleString("mySimpleStringProperty"), new SimpleString("mySimpleStringPropertyValue_" + i));
-         msg.putStringProperty(new SimpleString("myNullSimpleStringProperty"), (SimpleString) null);
+         msg.putStringProperty(SimpleString.of("mySimpleStringProperty"), SimpleString.of("mySimpleStringPropertyValue_" + i));
+         msg.putStringProperty(SimpleString.of("myNullSimpleStringProperty"), (SimpleString) null);
          producer.send(msg);
       }
 
@@ -181,17 +188,17 @@ public class XmlImportExportTest extends ActiveMQTestBase {
          assertEquals(i, msg.getIntProperty("myIntProperty").intValue());
          assertEquals(Long.MAX_VALUE - i, msg.getLongProperty("myLongProperty").longValue());
          assertEquals(i, msg.getObjectProperty("myObjectProperty"));
-         assertEquals(true, msg.getPropertyNames().contains(SimpleString.toSimpleString("myNullObjectProperty")));
-         assertEquals(null, msg.getObjectProperty("myNullObjectProperty"));
+         assertTrue(msg.getPropertyNames().contains(SimpleString.of("myNullObjectProperty")));
+         assertNull(msg.getObjectProperty("myNullObjectProperty"));
          assertEquals(Integer.valueOf(i).shortValue(), msg.getShortProperty("myShortProperty").shortValue());
          assertEquals("myStringPropertyValue_" + i, msg.getStringProperty("myStringProperty"));
-         assertEquals(true, msg.getPropertyNames().contains(SimpleString.toSimpleString("myNullStringProperty")));
-         assertEquals(null, msg.getStringProperty("myNullStringProperty"));
+         assertTrue(msg.getPropertyNames().contains(SimpleString.of("myNullStringProperty")));
+         assertNull(msg.getStringProperty("myNullStringProperty"));
          assertEquals(international.toString(), msg.getStringProperty("myNonAsciiStringProperty"));
          assertEquals(special, msg.getStringProperty("mySpecialCharacters"));
-         assertEquals(new SimpleString("mySimpleStringPropertyValue_" + i), msg.getSimpleStringProperty(new SimpleString("mySimpleStringProperty")));
-         assertEquals(true, msg.getPropertyNames().contains(SimpleString.toSimpleString("myNullSimpleStringProperty")));
-         assertEquals(null, msg.getSimpleStringProperty("myNullSimpleStringProperty"));
+         assertEquals(SimpleString.of("mySimpleStringPropertyValue_" + i), msg.getSimpleStringProperty(SimpleString.of("mySimpleStringProperty")));
+         assertTrue(msg.getPropertyNames().contains(SimpleString.of("myNullSimpleStringProperty")));
+         assertNull(msg.getSimpleStringProperty("myNullSimpleStringProperty"));
       }
    }
 
@@ -214,12 +221,12 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       return addClientSession(factory.createSession(false, true, true));
    }
 
-   @Test
+   @TestTemplate
    public void testMessageTypes() throws Exception {
 
       ClientSession session = basicSetUp();
 
-      session.createQueue(new QueueConfiguration(QUEUE_NAME));
+      session.createQueue(QueueConfiguration.of(QUEUE_NAME));
 
       ClientProducer producer = session.createProducer(QUEUE_NAME);
 
@@ -280,7 +287,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       assertEquals(Message.DEFAULT_TYPE, msg.getType());
    }
 
-   @Test
+   @TestTemplate
    public void testTextMessage() throws Exception {
       StringBuilder data = new StringBuilder();
       for (int i = 0; i < 2608; i++) {
@@ -289,7 +296,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
 
       ClientSession session = basicSetUp();
 
-      session.createQueue(new QueueConfiguration(QUEUE_NAME));
+      session.createQueue(QueueConfiguration.of(QUEUE_NAME));
 
       ClientProducer producer = session.createProducer(QUEUE_NAME);
       ClientMessage msg = session.createMessage(Message.TEXT_TYPE, true);
@@ -327,7 +334,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       assertEquals(data.toString(), msg.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testBytesMessage() throws Exception {
       StringBuilder data = new StringBuilder();
       for (int i = 0; i < 2610; i++) {
@@ -336,7 +343,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
 
       ClientSession session = basicSetUp();
 
-      session.createQueue(new QueueConfiguration(QUEUE_NAME));
+      session.createQueue(QueueConfiguration.of(QUEUE_NAME));
 
       ClientProducer producer = session.createProducer(QUEUE_NAME);
       ClientMessage msg = session.createMessage(Message.BYTES_TYPE, true);
@@ -376,12 +383,12 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       assertEquals(data.toString().getBytes().length, result.length);
    }
 
-   @Test
+   @TestTemplate
    public void testMessageAttributes() throws Exception {
 
       ClientSession session = basicSetUp();
 
-      session.createQueue(new QueueConfiguration(QUEUE_NAME));
+      session.createQueue(QueueConfiguration.of(QUEUE_NAME));
 
       ClientProducer producer = session.createProducer(QUEUE_NAME);
 
@@ -425,12 +432,12 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       assertNotNull(msg.getUserID());
    }
 
-   @Test
+   @TestTemplate
    public void testBindingAttributes() throws Exception {
       ClientSession session = basicSetUp();
 
-      session.createQueue(new QueueConfiguration("queueName1").setAddress("addressName1"));
-      session.createQueue(new QueueConfiguration("queueName2").setAddress("addressName1").setFilterString("bob"));
+      session.createQueue(QueueConfiguration.of("queueName1").setAddress("addressName1"));
+      session.createQueue(QueueConfiguration.of("queueName2").setAddress("addressName1").setFilterString("bob"));
 
       session.close();
       locator.close();
@@ -456,19 +463,19 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       xmlInputStream.reset();
       xmlDataImporter.process(xmlInputStream, session);
 
-      ClientSession.QueueQuery queueQuery = session.queueQuery(new SimpleString("queueName1"));
+      ClientSession.QueueQuery queueQuery = session.queueQuery(SimpleString.of("queueName1"));
 
       assertEquals("addressName1", queueQuery.getAddress().toString());
       assertNull(queueQuery.getFilterString());
 
-      queueQuery = session.queueQuery(new SimpleString("queueName2"));
+      queueQuery = session.queueQuery(SimpleString.of("queueName2"));
 
       assertEquals("addressName1", queueQuery.getAddress().toString());
       assertEquals("bob", queueQuery.getFilterString().toString());
-      assertEquals(true, queueQuery.isDurable());
+      assertTrue(queueQuery.isDurable());
    }
 
-   @Test
+   @TestTemplate
    public void testLargeMessage() throws Exception {
       server = createServer(true);
       server.start();
@@ -489,7 +496,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
 
       fileMessage.releaseResources(false, true);
 
-      session.createQueue(new QueueConfiguration("A"));
+      session.createQueue(QueueConfiguration.of("A"));
 
       ClientProducer prod = session.createProducer("A");
 
@@ -542,7 +549,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       session.commit();
    }
 
-   @Test
+   @TestTemplate
    public void testLargeMessagesNoTmpFiles() throws Exception {
       server = createServer(true);
       server.start();
@@ -563,7 +570,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
 
       fileMessage.releaseResources(false, true);
 
-      session.createQueue(new QueueConfiguration("A"));
+      session.createQueue(QueueConfiguration.of("A"));
 
       ClientProducer prod = session.createProducer("A");
 
@@ -626,17 +633,17 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       File workingDir = new File(System.getProperty("user.dir"));
       String[] flist = workingDir.list();
       for (String fn : flist) {
-         assertFalse("leftover: " + fn, fn.endsWith(".tmp"));
+         assertFalse(fn.endsWith(".tmp"), "leftover: " + fn);
       }
    }
 
-   @Test
+   @TestTemplate
    public void testLargeJmsTextMessage() throws Exception {
       basicSetUp();
       ConnectionFactory cf = ActiveMQJMSClient.createConnectionFactory("vm://0", "test");
       Connection c = cf.createConnection();
       Session s = c.createSession(false, Session.AUTO_ACKNOWLEDGE);
-      server.createQueue(new QueueConfiguration("A").setRoutingType(RoutingType.ANYCAST));
+      server.createQueue(QueueConfiguration.of("A").setRoutingType(RoutingType.ANYCAST));
       MessageProducer p = s.createProducer(ActiveMQJMSClient.createQueue("A"));
       p.setDeliveryMode(DeliveryMode.PERSISTENT);
       StringBuilder stringBuilder = new StringBuilder();
@@ -683,12 +690,12 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       c.close();
    }
 
-   @Test
+   @TestTemplate
    public void testPartialQueue() throws Exception {
       ClientSession session = basicSetUp();
 
-      session.createQueue(new QueueConfiguration("myQueue1").setAddress("myAddress"));
-      session.createQueue(new QueueConfiguration("myQueue2").setAddress("myAddress"));
+      session.createQueue(QueueConfiguration.of("myQueue1").setAddress("myAddress"));
+      session.createQueue(QueueConfiguration.of("myQueue2").setAddress("myAddress"));
 
       ClientProducer producer = session.createProducer("myAddress");
 
@@ -736,7 +743,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       assertNotNull(msg);
    }
 
-   @Test
+   @TestTemplate
    public void testPagedMessageWithMissingBinding() throws Exception {
       final String MY_ADDRESS = "myAddress";
       final String MY_QUEUE = "myQueue";
@@ -756,8 +763,8 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       ClientSessionFactory factory = locator.createSessionFactory();
       ClientSession session = factory.createSession(false, true, true);
 
-      session.createQueue(new QueueConfiguration(MY_QUEUE).setAddress(MY_ADDRESS));
-      session.createQueue(new QueueConfiguration(MY_QUEUE2).setAddress(MY_ADDRESS));
+      session.createQueue(QueueConfiguration.of(MY_QUEUE).setAddress(MY_ADDRESS));
+      session.createQueue(QueueConfiguration.of(MY_QUEUE2).setAddress(MY_ADDRESS));
 
       ClientProducer producer = session.createProducer(MY_ADDRESS);
 
@@ -809,7 +816,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       server.stop();
    }
 
-   @Test
+   @TestTemplate
    public void testPaging() throws Exception {
       final String MY_ADDRESS = "myAddress";
       final String MY_QUEUE = "myQueue";
@@ -828,7 +835,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       factory = createSessionFactory(locator);
       ClientSession session = factory.createSession(false, true, true);
 
-      session.createQueue(new QueueConfiguration(MY_QUEUE).setAddress(MY_ADDRESS));
+      session.createQueue(QueueConfiguration.of(MY_QUEUE).setAddress(MY_ADDRESS));
 
       ClientProducer producer = session.createProducer(MY_ADDRESS);
 
@@ -874,7 +881,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testPagedLargeMessage() throws Exception {
       final String MY_ADDRESS = "myAddress";
       final String MY_QUEUE = "myQueue";
@@ -893,7 +900,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       ClientSessionFactory factory = locator.createSessionFactory();
       ClientSession session = factory.createSession(false, true, true);
 
-      session.createQueue(new QueueConfiguration(MY_QUEUE).setAddress(MY_ADDRESS));
+      session.createQueue(QueueConfiguration.of(MY_QUEUE).setAddress(MY_ADDRESS));
 
       ClientProducer producer = session.createProducer(MY_ADDRESS);
 
@@ -968,11 +975,11 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       server.stop();
    }
 
-   @Test
+   @TestTemplate
    public void testTransactional() throws Exception {
       ClientSession session = basicSetUp();
 
-      session.createQueue(new QueueConfiguration(QUEUE_NAME));
+      session.createQueue(QueueConfiguration.of(QUEUE_NAME));
 
       ClientProducer producer = session.createProducer(QUEUE_NAME);
 
@@ -1010,7 +1017,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       assertNotNull(msg);
    }
 
-   @Test
+   @TestTemplate
    public void testBody() throws Exception {
       final String QUEUE_NAME = "A1";
       server = createServer(true);
@@ -1019,7 +1026,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       ClientSessionFactory factory = locator.createSessionFactory();
       ClientSession session = factory.createSession(false, true, true);
 
-      session.createQueue(new QueueConfiguration(QUEUE_NAME));
+      session.createQueue(QueueConfiguration.of(QUEUE_NAME));
 
       ClientProducer producer = session.createProducer(QUEUE_NAME);
 
@@ -1063,7 +1070,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       server.stop();
    }
 
-   @Test
+   @TestTemplate
    public void testBody2() throws Exception {
       final String QUEUE_NAME = "A1";
       server = createServer(true);
@@ -1072,7 +1079,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       ClientSessionFactory factory = locator.createSessionFactory();
       ClientSession session = factory.createSession(false, true, true);
 
-      session.createQueue(new QueueConfiguration(QUEUE_NAME));
+      session.createQueue(QueueConfiguration.of(QUEUE_NAME));
 
       ClientProducer producer = session.createProducer(QUEUE_NAME);
 
@@ -1124,17 +1131,17 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       server.stop();
    }
 
-   @Test
+   @TestTemplate
    public void testRoutingTypes() throws Exception {
-      SimpleString myAddress = SimpleString.toSimpleString("myAddress");
+      SimpleString myAddress = SimpleString.of("myAddress");
       ClientSession session = basicSetUp();
 
       EnumSet<RoutingType> routingTypes = EnumSet.of(RoutingType.ANYCAST, RoutingType.MULTICAST);
 
       session.createAddress(myAddress, routingTypes, false);
 
-      session.createQueue(new QueueConfiguration("myQueue1").setAddress(myAddress));
-      session.createQueue(new QueueConfiguration("myQueue2").setAddress(myAddress));
+      session.createQueue(QueueConfiguration.of("myQueue1").setAddress(myAddress));
+      session.createQueue(QueueConfiguration.of("myQueue2").setAddress(myAddress));
 
       locator.close();
       server.stop();
@@ -1164,9 +1171,9 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       assertTrue(server.getAddressInfo(myAddress).getRoutingTypes().contains(RoutingType.MULTICAST));
    }
 
-   @Test
+   @TestTemplate
    public void testEmptyRoutingTypes() throws Exception {
-      SimpleString myAddress = SimpleString.toSimpleString("myAddress");
+      SimpleString myAddress = SimpleString.of("myAddress");
       ClientSession session = basicSetUp();
 
       EnumSet<RoutingType> routingTypes = EnumSet.noneOf(RoutingType.class);
@@ -1200,12 +1207,12 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       assertEquals(0, server.getAddressInfo(myAddress).getRoutingTypes().size());
    }
 
-   @Test
+   @TestTemplate
    public void testImportWrongRoutingType() throws Exception {
-      SimpleString myAddress = SimpleString.toSimpleString("myAddress");
-      SimpleString myQueue = SimpleString.toSimpleString("myQueue");
-      SimpleString dla = SimpleString.toSimpleString("DLA");
-      SimpleString dlaPrefix = SimpleString.toSimpleString("DLA.");
+      SimpleString myAddress = SimpleString.of("myAddress");
+      SimpleString myQueue = SimpleString.of("myQueue");
+      SimpleString dla = SimpleString.of("DLA");
+      SimpleString dlaPrefix = SimpleString.of("DLA.");
       String payload = "myMessagePayload";
 
       server = createServer(true);
@@ -1217,7 +1224,7 @@ public class XmlImportExportTest extends ActiveMQTestBase {
       //Create ANYCAST queue and set "AutoCreateDeadLetterResources"
       //Send message with ANYCAST RoutingType
       server.getAddressSettingsRepository().addMatch(myAddress.toString(), new AddressSettings().setMaxDeliveryAttempts(1).setDeadLetterAddress(dla).setAutoCreateDeadLetterResources(true).setDeadLetterQueuePrefix(dlaPrefix).setMaxReadPageBytes(-1).setMaxReadPageMessages(-1));
-      session.createQueue(new QueueConfiguration(myQueue).setAddress(myAddress).setDurable(true).setRoutingType(RoutingType.ANYCAST));
+      session.createQueue(QueueConfiguration.of(myQueue).setAddress(myAddress).setDurable(true).setRoutingType(RoutingType.ANYCAST));
 
       ClientProducer producer = session.createProducer(myAddress);
       producer.send(createTextMessage(session, payload).putByteProperty(Message.HDR_ROUTING_TYPE, (byte) 1));
