@@ -16,7 +16,7 @@
  */
 package org.apache.activemq.artemis.tests.integration.server;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class AIOFileLockTimeoutTest extends FileLockTimeoutTest {
 
