@@ -16,6 +16,10 @@
  */
 package org.apache.activemq.artemis.tests.integration.stomp;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import javax.jms.BytesMessage;
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
@@ -25,6 +29,7 @@ import javax.jms.Queue;
 import javax.jms.Session;
 import javax.jms.TextMessage;
 import javax.jms.Topic;
+import java.lang.invoke.MethodHandles;
 import java.io.IOException;
 import java.net.URI;
 import java.net.URISyntaxException;
@@ -51,34 +56,30 @@ import org.apache.activemq.artemis.core.server.ActiveMQServers;
 import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
 import org.apache.activemq.artemis.jms.client.ActiveMQJMSConnectionFactory;
 import org.apache.activemq.artemis.spi.core.security.ActiveMQJAASSecurityManager;
+import org.apache.activemq.artemis.tests.extensions.parameterized.Parameter;
+import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.activemq.artemis.tests.extensions.parameterized.Parameters;
 import org.apache.activemq.artemis.tests.integration.stomp.util.AbstractStompClientConnection;
 import org.apache.activemq.artemis.tests.integration.stomp.util.ClientStompFrame;
 import org.apache.activemq.artemis.tests.integration.stomp.util.StompClientConnection;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
-import org.apache.activemq.artemis.utils.RetryRule;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import java.lang.invoke.MethodHandles;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public abstract class StompTestBase extends ActiveMQTestBase {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
-   @Parameterized.Parameter
+   @Parameter(index = 0)
    public String scheme;
 
-   @Rule
-   public RetryRule retryRule = new RetryRule(2);
-
    protected URI uri;
 
-   @Parameterized.Parameters(name = "{0}")
+   @Parameters(name = "{0}")
    public static Collection<Object[]> data() {
       return Arrays.asList(new Object[][]{{"ws+v10.stomp"}, {"tcp+v10.stomp"}});
    }
@@ -134,7 +135,7 @@ public abstract class StompTestBase extends ActiveMQTestBase {
    }
 
    @Override
-   @Before
+   @BeforeEach
    public void setUp() throws Exception {
       super.setUp();
 
@@ -161,21 +162,25 @@ public abstract class StompTestBase extends ActiveMQTestBase {
    }
 
    @Override
-   @After
+   @AfterEach
    public void tearDown() throws Exception {
-      if (connection != null) {
-         connection.close();
+      try {
+         if (connection != null) {
+            connection.close();
+         }
+      } finally {
+         try {
+            tearDownConnections();
+         } finally {
+            super.tearDown();
+         }
       }
-      super.tearDown();
    }
 
-
-   @After
    public void tearDownConnections() {
       AbstractStompClientConnection.tearDownConnections();
    }
 
-
    /**
     * @return
     * @throws Exception
@@ -194,7 +199,7 @@ public abstract class StompTestBase extends ActiveMQTestBase {
                                                 .addAcceptorConfiguration("stomp", stompAcceptorURI)
                                                 .addAcceptorConfiguration(new TransportConfiguration(InVMAcceptorFactory.class.getName()))
                                                 .setConnectionTtlCheckInterval(500)
-                                                .addQueueConfiguration(new QueueConfiguration(getQueueName()).setRoutingType(RoutingType.ANYCAST))
+                                                .addQueueConfiguration(QueueConfiguration.of(getQueueName()).setRoutingType(RoutingType.ANYCAST))
                                                 .addAddressConfiguration(new CoreAddressConfiguration().setName(getTopicName()).addRoutingType(RoutingType.MULTICAST));
 
       if (getIncomingInterceptors() != null) {
@@ -214,7 +219,7 @@ public abstract class StompTestBase extends ActiveMQTestBase {
 
          final String role = "testRole";
          securityManager.getConfiguration().addRole(defUser, role);
-         config.getSecurityRoles().put("#", new HashSet<Role>(Set.of(new Role(role, true, true, true, true, true, true, true, true, true, true))));
+         config.getSecurityRoles().put("#", new HashSet<Role>(Set.of(new Role(role, true, true, true, true, true, true, true, true, true, true, false, false))));
       }
 
       return activeMQServer;
@@ -308,7 +313,7 @@ public abstract class StompTestBase extends ActiveMQTestBase {
       String messageID = messageIdFrame.getHeader(Stomp.Headers.Message.MESSAGE_ID);
 
       ClientStompFrame frame = conn.createFrame(Stomp.Commands.ACK)
-                                      .addHeader(Stomp.Headers.Message.MESSAGE_ID, messageID);
+                                      .addHeader(Stomp.Headers.Ack.MESSAGE_ID, messageID);
 
       if (subscriptionId != null) {
          frame.addHeader(Stomp.Headers.Ack.SUBSCRIPTION, subscriptionId);
@@ -337,7 +342,7 @@ public abstract class StompTestBase extends ActiveMQTestBase {
    public static void nack(StompClientConnection conn, String subscriptionId, String messageId) throws IOException, InterruptedException {
       ClientStompFrame frame = conn.createFrame(Stomp.Commands.NACK)
                                       .addHeader(Stomp.Headers.Ack.SUBSCRIPTION, subscriptionId)
-                                      .addHeader(Stomp.Headers.Message.MESSAGE_ID, messageId);
+                                      .addHeader(Stomp.Headers.Ack.MESSAGE_ID, messageId);
 
       conn.sendFrame(frame);
    }
@@ -525,7 +530,7 @@ public abstract class StompTestBase extends ActiveMQTestBase {
       }
 
       if (receipt) {
-         assertNotNull("Requested receipt, but response is null", frame);
+         assertNotNull(frame, "Requested receipt, but response is null");
          assertTrue(frame.getHeader(Stomp.Headers.Response.RECEIPT_ID).equals(uuid));
       }
 
