@@ -16,6 +16,9 @@
  */
 package org.apache.activemq.artemis.tests.smoke.console;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import org.apache.activemq.artemis.api.core.RoutingType;
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.api.core.management.ObjectNameBuilder;
@@ -23,34 +26,29 @@ import org.apache.activemq.artemis.cli.commands.ActionContext;
 import org.apache.activemq.artemis.cli.commands.messages.Consumer;
 import org.apache.activemq.artemis.cli.commands.messages.Producer;
 import org.apache.activemq.artemis.cli.commands.queue.CreateQueue;
+import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedTestExtension;
 import org.apache.activemq.artemis.tests.smoke.console.pages.LoginPage;
 import org.apache.activemq.artemis.tests.smoke.console.pages.MessagePage;
 import org.apache.activemq.artemis.tests.smoke.console.pages.QueuePage;
 import org.apache.activemq.artemis.tests.smoke.console.pages.QueuesPage;
 import org.apache.activemq.artemis.tests.smoke.console.pages.SendMessagePage;
 import org.apache.activemq.artemis.tests.smoke.console.pages.StatusPage;
-import org.apache.activemq.artemis.utils.RetryRule;
 import org.apache.activemq.artemis.utils.Wait;
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.openqa.selenium.MutableCapabilities;
 
 import javax.management.ObjectName;
 
-@RunWith(Parameterized.class)
+// Parameters set in super class
+@ExtendWith(ParameterizedTestExtension.class)
 public class QueuesTest extends ConsoleTest {
 
-   @Rule
-   public RetryRule retryRule = new RetryRule(2);
-
    public QueuesTest(MutableCapabilities browserOptions) {
       super(browserOptions);
    }
 
-   @Test
+   @TestTemplate
    public void testDefaultQueues() throws Exception {
       driver.get(webServerUrl + "/console");
       LoginPage loginPage = new LoginPage(driver);
@@ -65,7 +63,7 @@ public class QueuesTest extends ConsoleTest {
       assertEquals(0, queuesPage.getMessagesCount("ExpiryQueue"));
    }
 
-   @Test
+   @TestTemplate
    public void testAutoCreatedQueue() throws Exception {
       final long messages = 1;
       final String queueName = "TEST";
@@ -114,12 +112,12 @@ public class QueuesTest extends ConsoleTest {
       Wait.assertEquals(0, () -> afterQueuesPage.getMessagesCount(queueName));
    }
 
-   @Test
+   @TestTemplate
    public void testDefaultExpiryQueue() throws Exception {
       testExpiryQueue("TEST", "ExpiryQueue");
    }
 
-   @Test
+   @TestTemplate
    public void testCustomExpiryQueue() throws Exception {
       final ObjectNameBuilder objectNameBuilder = ObjectNameBuilder.create(null, "0.0.0.0", true);
       final ObjectName activeMQServerObjectName = objectNameBuilder.getActiveMQServerObjectName();
@@ -129,10 +127,10 @@ public class QueuesTest extends ConsoleTest {
       StatusPage statusPage = loginPage.loginValidUser(
          SERVER_ADMIN_USERNAME, SERVER_ADMIN_PASSWORD, DEFAULT_TIMEOUT);
 
-      Assert.assertTrue(statusPage.postJolokiaExecRequest(activeMQServerObjectName.getCanonicalName(),
+      assertTrue(statusPage.postJolokiaExecRequest(activeMQServerObjectName.getCanonicalName(),
          "createQueue(java.lang.String,java.lang.String,java.lang.String)",
          "\"foo\",\"foo\",\"ANYCAST\"").toString().contains("\"status\":200"));
-      Assert.assertTrue(statusPage.postJolokiaExecRequest(activeMQServerObjectName.getCanonicalName(),
+      assertTrue(statusPage.postJolokiaExecRequest(activeMQServerObjectName.getCanonicalName(),
          "addAddressSettings(java.lang.String,java.lang.String,java.lang.String,long,boolean,int,long,int,int,long,double,long,long,boolean,java.lang.String,long,long,java.lang.String,boolean,boolean,boolean,boolean)",
          "\"bar\",\"DLA\",\"foo\",-1,false,0,0,0,0,0,\"0\",0,0,false,\"\",-1,0,\"\",false,false,false,false").toString().contains("\"status\":200"));
 
@@ -145,19 +143,19 @@ public class QueuesTest extends ConsoleTest {
       final String messageText = "TEST";
       final ObjectNameBuilder objectNameBuilder = ObjectNameBuilder.create(null, "0.0.0.0", true);
       final ObjectName expiryQueueObjectName = objectNameBuilder.getQueueObjectName(
-         SimpleString.toSimpleString(expiryQueueName),
-         SimpleString.toSimpleString(expiryQueueName),
+         SimpleString.of(expiryQueueName),
+         SimpleString.of(expiryQueueName),
          RoutingType.ANYCAST);
       final ObjectName testQueueObjectName = objectNameBuilder.getQueueObjectName(
-         SimpleString.toSimpleString(queueName),
-         SimpleString.toSimpleString(queueName),
+         SimpleString.of(queueName),
+         SimpleString.of(queueName),
          RoutingType.ANYCAST);
 
       driver.get(webServerUrl + "/console");
       LoginPage loginPage = new LoginPage(driver);
       StatusPage statusPage = loginPage.loginValidUser(
          SERVER_ADMIN_USERNAME, SERVER_ADMIN_PASSWORD, DEFAULT_TIMEOUT);
-      Assert.assertTrue(statusPage.postJolokiaExecRequest(expiryQueueObjectName.getCanonicalName(),
+      assertTrue(statusPage.postJolokiaExecRequest(expiryQueueObjectName.getCanonicalName(),
          "removeAllMessages()", "").toString().contains("\"status\":200"));
 
       QueuesPage beforeQueuesPage = statusPage.getQueuesPage(DEFAULT_TIMEOUT);
@@ -185,9 +183,9 @@ public class QueuesTest extends ConsoleTest {
       sendMessagePage.sendMessage();
 
       QueuePage queuePage = sendMessagePage.getQueuesPage(DEFAULT_TIMEOUT).getQueuePage(queueName, DEFAULT_TIMEOUT);
-      Assert.assertTrue(queuePage.postJolokiaExecRequest(testQueueObjectName.getCanonicalName(), "expireMessage(long)",
+      assertTrue(queuePage.postJolokiaExecRequest(testQueueObjectName.getCanonicalName(), "expireMessage(long)",
          String.valueOf(queuePage.getMessageId(0))).toString().contains("\"status\":200"));
-      Assert.assertTrue(queuePage.postJolokiaExecRequest(testQueueObjectName.getCanonicalName(), "expireMessage(long)",
+      assertTrue(queuePage.postJolokiaExecRequest(testQueueObjectName.getCanonicalName(), "expireMessage(long)",
          String.valueOf(queuePage.getMessageId(1))).toString().contains("\"status\":200"));
 
       QueuesPage afterQueuesPage = queuePage.getQueuesPage(DEFAULT_TIMEOUT);
@@ -201,7 +199,7 @@ public class QueuesTest extends ConsoleTest {
       assertEquals(queueName, expiryPage.getMessageOriginalQueue(1));
    }
 
-   @Test
+   @TestTemplate
    public void testSendMessageUsingCurrentLogonUser() throws Exception {
       final String queueName = "TEST";
       final String messageText = "TEST";
@@ -218,8 +216,8 @@ public class QueuesTest extends ConsoleTest {
       createQueueCommand.setUser(SERVER_ADMIN_USERNAME);
       createQueueCommand.setPassword(SERVER_ADMIN_PASSWORD);
       createQueueCommand.setName(queueName);
-      createQueueCommand.setMulticast(true);
-      createQueueCommand.setAnycast(false);
+      createQueueCommand.setMulticast(false);
+      createQueueCommand.setAnycast(true);
       createQueueCommand.setAutoCreateAddress(true);
       createQueueCommand.execute(new ActionContext());
 
